# Resources
from lob.resource import (
    Address,
    BankAccount,
    BulkUSVerification,
    BulkIntlVerification,
    Card,
    CardOrder,
    Check,
    Letter,
    Postcard,
    SelfMailer,
    USAutocompletion,
    USReverseGeocodeLookup,
    USVerification,
    USZipLookup,
    IntlVerification
)

from lob.version import VERSION

api_key = None
api_base = 'https://api.lob.com/v1'
